diff --git a/CHANGELOG.md b/CHANGELOG.md
index 656f824a..ec069f60 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,5 +1,9 @@
# OpenStudio Model Articulation Gems
+## Version 0.11.1
+* Update 'story_multiplier' argument to 'story_multiplier_method' for create_bar_from_building_type_ratios measure
+* Update dependencies for 3.9
+
## Version 0.11.0
* Support for OpenStudio 3.9 (upgrade to standards gem 0.7.0, extension gem 0.8.1)
* Fixed [#129]( https://github.com/NREL/openstudio-model-articulation-gem/issues/129 ), Radiance measure needs to be updated for new E+ output variable
diff --git a/Gemfile b/Gemfile
index f484affb..69b07ec1 100644
--- a/Gemfile
+++ b/Gemfile
@@ -19,8 +19,8 @@ allow_local = ENV['FAVOR_LOCAL_GEMS']
# gem 'bcl', :git => 'https://github.com/wenyikuang/bcl-gem.git', :branch => 'develop'
# Only uncomment if you need to test a different version of the extension gem
-if allow_local && File.exist?('../OpenStudio-extension-gem')
- gem 'openstudio-extension', path: '../OpenStudio-extension-gem'
-elsif allow_local
- gem 'openstudio-extension', github: 'NREL/OpenStudio-extension-gem', branch: 'develop'
-end
+# if allow_local && File.exist?('../OpenStudio-extension-gem')
+# gem 'openstudio-extension', path: '../OpenStudio-extension-gem'
+# elsif allow_local
+# gem 'openstudio-extension', github: 'NREL/OpenStudio-extension-gem', branch: 'develop'
+# end
diff --git a/lib/measures/create_bar_from_building_type_ratios/README.md b/lib/measures/create_bar_from_building_type_ratios/README.md
index f0659421..1c8226b9 100644
--- a/lib/measures/create_bar_from_building_type_ratios/README.md
+++ b/lib/measures/create_bar_from_building_type_ratios/README.md
@@ -584,7 +584,7 @@ This should be true unless you are modeling a partial building which doesn't inc
### Calculation Method for Story Multiplier
-**Name:** story_multiplier,
+**Name:** story_multiplier_method,
**Type:** Choice,
**Units:** ,
**Required:** true,
diff --git a/lib/measures/create_bar_from_building_type_ratios/measure.xml b/lib/measures/create_bar_from_building_type_ratios/measure.xml
index 0273ce9a..017c25d4 100644
--- a/lib/measures/create_bar_from_building_type_ratios/measure.xml
+++ b/lib/measures/create_bar_from_building_type_ratios/measure.xml
@@ -3,8 +3,8 @@
3.1
create_bar_from_building_type_ratios
6e3a14f8-c3c7-4e03-bc51-bef8a52e1a05
- 89c35873-5698-4e69-81a9-b7781fd3965e
- 2024-11-16T23:56:32Z
+ 53acfac0-33c0-4f7f-9cd1-45ee9b483507
+ 2025-01-09T08:07:48Z
2AF3A68E
CreateBarFromBuildingTypeRatios
Create Bar From Building Type Ratios
@@ -1199,7 +1199,7 @@
- story_multiplier
+ story_multiplier_method
Calculation Method for Story Multiplier
Choice
true
@@ -1353,7 +1353,7 @@
README.md
md
readme
- 9AB9F376
+ 5E1C4DB0
README.md.erb
@@ -1496,13 +1496,13 @@
measure.rb
rb
script
- 153D5528
+ 0DE63CCC
create_bar_from_building_type_ratios_test.rb
rb
test
- 2E1610BC
+ CD016F6B
example_model.osm
diff --git a/lib/measures/create_bar_from_building_type_ratios/tests/create_bar_from_building_type_ratios_test.rb b/lib/measures/create_bar_from_building_type_ratios/tests/create_bar_from_building_type_ratios_test.rb
index 14677ee7..6912ce82 100644
--- a/lib/measures/create_bar_from_building_type_ratios/tests/create_bar_from_building_type_ratios_test.rb
+++ b/lib/measures/create_bar_from_building_type_ratios/tests/create_bar_from_building_type_ratios_test.rb
@@ -78,7 +78,7 @@ def test_no_multiplier
args = {}
args['total_bldg_floor_area'] = 50000.0
args['num_stories_above_grade'] = 5
- args['story_multiplier'] = 'None'
+ args['story_multiplier_method'] = 'None'
apply_measure_to_model(__method__.to_s.gsub('test_', ''), args, 'example_model.osm')
end
@@ -1031,7 +1031,7 @@ def test_custom_offset
args['building_rotation'] = 0
args['make_mid_story_surfaces_adiabatic'] = true
args['bar_sep_dist_mult'] = 3
- args['story_multiplier'] = 'None'
+ args['story_multiplier_method'] = 'None'
args['num_stories_below_grade'] = 0
args['bar_width'] = 60.0
@@ -1053,7 +1053,7 @@ def test_custom_offset_alt
args['building_rotation'] = 0
args['make_mid_story_surfaces_adiabatic'] = true
args['bar_sep_dist_mult'] = 3
- # args['story_multiplier'] = 'None'
+ # args['story_multiplier_method'] = 'None'
# args['num_stories_below_grade'] = 1
# args['party_wall_stories_south'] = 1
# args['party_wall_stories_east'] = 2
@@ -1077,12 +1077,12 @@ def test_custom_offset_alt2
args['building_rotation'] = 0
args['make_mid_story_surfaces_adiabatic'] = true
args['bar_sep_dist_mult'] = 3
- # args['story_multiplier'] = 'None'
+ # args['story_multiplier_method'] = 'None'
# args['num_stories_below_grade'] = 1
# args['party_wall_stories_south'] = 1
# args['party_wall_stories_east'] = 2
args['space_type_sort_logic'] = 'Size'
- # args['story_multiplier'] = "None"
+ # args['story_multiplier_method'] = "None"
apply_measure_to_model(__method__.to_s.gsub('test_', ''), args, nil, nil, nil)
end
diff --git a/lib/measures/create_bar_from_deer_building_type_ratios/README.md b/lib/measures/create_bar_from_deer_building_type_ratios/README.md
index 25679452..2da273dd 100644
--- a/lib/measures/create_bar_from_deer_building_type_ratios/README.md
+++ b/lib/measures/create_bar_from_deer_building_type_ratios/README.md
@@ -684,7 +684,7 @@ This should be true unless you are modeling a partial building which doesn't inc
### Calculation Method for Story Multiplier
-**Name:** story_multiplier,
+**Name:** story_multiplier_method,
**Type:** Choice,
**Units:** ,
**Required:** true,
diff --git a/lib/measures/create_bar_from_deer_building_type_ratios/measure.xml b/lib/measures/create_bar_from_deer_building_type_ratios/measure.xml
index c3d1514b..e650c799 100644
--- a/lib/measures/create_bar_from_deer_building_type_ratios/measure.xml
+++ b/lib/measures/create_bar_from_deer_building_type_ratios/measure.xml
@@ -3,8 +3,8 @@
3.1
create_bar_from_deer_building_type_ratios
aa4a7ecf-5bfd-4c5e-b0ca-e68babbacff1
- deff6402-221d-44c9-ad2c-a6612604e237
- 2024-11-16T23:56:36Z
+ 0b3bb574-a085-4309-b4b5-102ef23d7477
+ 2025-01-09T08:07:51Z
B31F0C1F
CreateBarFromDEERBuildingTypeRatios
Create Bar From DEER Building Type Ratios
@@ -823,7 +823,7 @@
- story_multiplier
+ story_multiplier_method
Calculation Method for Story Multiplier
Choice
true
@@ -988,7 +988,7 @@
README.md
md
readme
- 38647660
+ 954998A9
README.md.erb
@@ -1131,7 +1131,7 @@
measure.rb
rb
script
- DC57753C
+ 3927215A
create_bar_from_deer_building_type_ratios_test.rb
diff --git a/lib/measures/create_bar_from_doe_building_type_ratios/README.md b/lib/measures/create_bar_from_doe_building_type_ratios/README.md
index 9a6fb3f8..24c70cee 100644
--- a/lib/measures/create_bar_from_doe_building_type_ratios/README.md
+++ b/lib/measures/create_bar_from_doe_building_type_ratios/README.md
@@ -673,7 +673,7 @@ This should be true unless you are modeling a partial building which doesn't inc
### Calculation Method for Story Multiplier
-**Name:** story_multiplier,
+**Name:** story_multiplier_method,
**Type:** Choice,
**Units:** ,
**Required:** true,
diff --git a/lib/measures/create_bar_from_doe_building_type_ratios/measure.xml b/lib/measures/create_bar_from_doe_building_type_ratios/measure.xml
index 286faf71..b65b1419 100644
--- a/lib/measures/create_bar_from_doe_building_type_ratios/measure.xml
+++ b/lib/measures/create_bar_from_doe_building_type_ratios/measure.xml
@@ -3,8 +3,8 @@
3.1
create_bar_from_doe_building_type_ratios
0de3cff9-c805-42c4-964e-18cb43a22c63
- 21d5e86d-8249-48df-8e5f-ec726ccce137
- 2024-11-16T23:56:37Z
+ a0381b1d-0db5-41fd-b51c-f03e3afd035c
+ 2025-01-09T08:07:51Z
5F523097
CreateBarFromDOEBuildingTypeRatios
Create Bar From DOE Building Type Ratios
@@ -759,7 +759,7 @@
- story_multiplier
+ story_multiplier_method
Calculation Method for Story Multiplier
Choice
true
@@ -928,7 +928,7 @@
README.md
md
readme
- B96F2633
+ BEEE10DB
README.md.erb
@@ -1071,13 +1071,13 @@
measure.rb
rb
script
- AF357BC7
+ CCC0C7D4
create_bar_from_doe_building_type_ratios_test.rb
rb
test
- 7286FEA7
+ A08A5602
example_model.osm
diff --git a/lib/measures/create_bar_from_doe_building_type_ratios/tests/create_bar_from_doe_building_type_ratios_test.rb b/lib/measures/create_bar_from_doe_building_type_ratios/tests/create_bar_from_doe_building_type_ratios_test.rb
index 46d1d408..f03f4903 100644
--- a/lib/measures/create_bar_from_doe_building_type_ratios/tests/create_bar_from_doe_building_type_ratios_test.rb
+++ b/lib/measures/create_bar_from_doe_building_type_ratios/tests/create_bar_from_doe_building_type_ratios_test.rb
@@ -78,7 +78,7 @@ def test_no_multiplier
args = {}
args['total_bldg_floor_area'] = 50000.0
args['num_stories_above_grade'] = 5
- args['story_multiplier'] = 'None'
+ args['story_multiplier_method'] = 'None'
apply_measure_to_model(__method__.to_s.gsub('test_', ''), args, 'example_model.osm')
end
diff --git a/lib/measures/create_bar_from_space_type_ratios/README.md b/lib/measures/create_bar_from_space_type_ratios/README.md
index 535e9024..225fb967 100644
--- a/lib/measures/create_bar_from_space_type_ratios/README.md
+++ b/lib/measures/create_bar_from_space_type_ratios/README.md
@@ -491,7 +491,7 @@ This should be true unless you are modeling a partial building which doesn't inc
### Calculation Method for Story Multiplier
-**Name:** story_multiplier,
+**Name:** story_multiplier_method,
**Type:** Choice,
**Units:** ,
**Required:** true,
diff --git a/lib/measures/create_bar_from_space_type_ratios/measure.xml b/lib/measures/create_bar_from_space_type_ratios/measure.xml
index 2199eb7a..36481c50 100644
--- a/lib/measures/create_bar_from_space_type_ratios/measure.xml
+++ b/lib/measures/create_bar_from_space_type_ratios/measure.xml
@@ -3,8 +3,8 @@
3.1
create_bar_from_space_type_ratios
3e988765-9673-46f8-9b65-99d5b86c2b22
- 3220d2d2-1d1b-465c-92ba-bd0fa5ea83d8
- 2024-11-16T23:56:38Z
+ b03d451a-d0af-44c5-baf6-d5e91af68e2e
+ 2025-01-09T08:07:51Z
49BEF039
CreateBarFromSpaceTypeRatios
Create Bar From Space Type Ratios
@@ -427,7 +427,7 @@
- story_multiplier
+ story_multiplier_method
Calculation Method for Story Multiplier
Choice
true
@@ -581,7 +581,7 @@
README.md
md
readme
- 6BF1D1B6
+ 8E3C144C
README.md.erb
@@ -724,13 +724,13 @@
measure.rb
rb
script
- 57CFCE32
+ 9EFE7662
create_bar_from_space_type_ratios_test.rb
rb
test
- 0A68D7F4
+ C1493A39
diff --git a/lib/measures/create_bar_from_space_type_ratios/tests/create_bar_from_space_type_ratios_test.rb b/lib/measures/create_bar_from_space_type_ratios/tests/create_bar_from_space_type_ratios_test.rb
index f561dd55..43e0323d 100644
--- a/lib/measures/create_bar_from_space_type_ratios/tests/create_bar_from_space_type_ratios_test.rb
+++ b/lib/measures/create_bar_from_space_type_ratios/tests/create_bar_from_space_type_ratios_test.rb
@@ -136,9 +136,9 @@ def test_custom_a
args['building_rotation'] = 0
args['make_mid_story_surfaces_adiabatic'] = true
args['bar_sep_dist_mult'] = 3
- args['story_multiplier'] = 'None'
+ args['story_multiplier_method'] = 'None'
args['space_type_sort_logic'] = 'Building Type > Size'
- args['story_multiplier'] = 'None'
+ args['story_multiplier_method'] = 'None'
apply_measure_to_model(__method__.to_s.gsub('test_', ''), args, nil, nil, nil)
end
diff --git a/lib/openstudio/model_articulation/version.rb b/lib/openstudio/model_articulation/version.rb
index 5d1ad6de..8d51e3ea 100644
--- a/lib/openstudio/model_articulation/version.rb
+++ b/lib/openstudio/model_articulation/version.rb
@@ -5,6 +5,6 @@
module OpenStudio
module ModelArticulation
- VERSION = '0.11.0'
+ VERSION = '0.11.1'
end
end
diff --git a/openstudio-model-articulation.gemspec b/openstudio-model-articulation.gemspec
index 8ad39148..50595824 100644
--- a/openstudio-model-articulation.gemspec
+++ b/openstudio-model-articulation.gemspec
@@ -29,13 +29,12 @@ Gem::Specification.new do |spec|
spec.required_ruby_version = '~> 3.2.2'
spec.add_dependency 'bundler', '~> 2.4.10'
- spec.add_dependency 'openstudio-extension', '~> 0.8.2'
- spec.add_dependency 'openstudio-standards', '0.7.0'
+ spec.add_dependency 'openstudio-extension', '~> 0.8.3'
+ spec.add_dependency 'openstudio-standards', '0.7.1'
- # if we need the following dependencies pinned,
+ # if we need the following dependencies pinned,
# let's set them in extension-gem for next release
spec.add_dependency 'multipart-post', '2.4.0'
- spec.add_dependency 'addressable', '2.8.1'
spec.add_development_dependency 'rake', '~> 13.0'
spec.add_development_dependency 'rspec', '~> 3.9'
diff --git a/lib/measures/create_bar_from_building_type_ratios/measure.rb b/lib/measures/create_bar_from_building_type_ratios/measure.rb
index cf221376..8c08b9f9 100644
--- a/lib/measures/create_bar_from_building_type_ratios/measure.rb
+++ b/lib/measures/create_bar_from_building_type_ratios/measure.rb
@@ -341,15 +341,15 @@ def arguments(model)
top_story_exterior_exposed_roof.setDefaultValue(true)
args << top_story_exterior_exposed_roof
# Make argument for story_multiplier
choices = OpenStudio::StringVector.new
choices << 'None'
choices << 'Basements Ground Mid Top'
# choices << "Basements Ground Midx5 Top"
- story_multiplier = OpenStudio::Measure::OSArgument.makeChoiceArgument('story_multiplier', choices, true)
- story_multiplier.setDisplayName('Calculation Method for Story Multiplier')
- story_multiplier.setDefaultValue('Basements Ground Mid Top')
- args << story_multiplier
+ story_multiplier_method = OpenStudio::Measure::OSArgument.makeChoiceArgument('story_multiplier_method', choices, true)
+ story_multiplier_method.setDisplayName('Calculation Method for Story Multiplier')
+ story_multiplier_method.setDefaultValue('Basements Ground Mid Top')
+ args << story_multiplier_method
# make an argument for make_mid_story_surfaces_adiabatic (added to avoid issues with intersect and to lower surface count when using individual stories sliced)
make_mid_story_surfaces_adiabatic = OpenStudio::Measure::OSArgument.makeBoolArgument('make_mid_story_surfaces_adiabatic', true)
@@ -341,15 +341,15 @@ def arguments(model)
top_story_exterior_exposed_roof.setDefaultValue(true)
args << top_story_exterior_exposed_roof
- # Make argument for story_multiplier
+ # Make argument for story_multiplier_method
choices = OpenStudio::StringVector.new
choices << 'None'
diff --git a/lib/measures/create_bar_from_deer_building_type_ratios/measure.rb b/lib/measures/create_bar_from_deer_building_type_ratios/measure.rb
index dfedd852..2b8a42e2 100644
--- a/lib/measures/create_bar_from_deer_building_type_ratios/measure.rb
+++ b/lib/measures/create_bar_from_deer_building_type_ratios/measure.rb
@@ -313,15 +313,15 @@ def arguments(model)
top_story_exterior_exposed_roof.setDefaultValue(true)
args << top_story_exterior_exposed_roof
# Make argument for story_multiplier
choices = OpenStudio::StringVector.new
choices << 'None'
choices << 'Basements Ground Mid Top'
# choices << "Basements Ground Midx5 Top"
- story_multiplier = OpenStudio::Measure::OSArgument.makeChoiceArgument('story_multiplier', choices, true)
- story_multiplier.setDisplayName('Calculation Method for Story Multiplier')
- story_multiplier.setDefaultValue('Basements Ground Mid Top')
- args << story_multiplier
+ story_multiplier_method = OpenStudio::Measure::OSArgument.makeChoiceArgument('story_multiplier_method', choices, true)
+ story_multiplier_method.setDisplayName('Calculation Method for Story Multiplier')
+ story_multiplier_method.setDefaultValue('Basements Ground Mid Top')
+ args << story_multiplier_method
# make an argument for make_mid_story_surfaces_adiabatic (added to avoid issues with intersect and to lower surface count when using individual stories sliced)
make_mid_story_surfaces_adiabatic = OpenStudio::Measure::OSArgument.makeBoolArgument('make_mid_story_surfaces_adiabatic', true)
@@ -313,15 +313,15 @@ def arguments(model)
top_story_exterior_exposed_roof.setDefaultValue(true)
args << top_story_exterior_exposed_roof
- # Make argument for story_multiplier
+ # Make argument for story_multiplier_method
choices = OpenStudio::StringVector.new
choices << 'None'
diff --git a/lib/measures/create_bar_from_doe_building_type_ratios/measure.rb b/lib/measures/create_bar_from_doe_building_type_ratios/measure.rb
index 48cc55f2..e446ff86 100644
--- a/lib/measures/create_bar_from_doe_building_type_ratios/measure.rb
+++ b/lib/measures/create_bar_from_doe_building_type_ratios/measure.rb
@@ -314,15 +314,15 @@ def arguments(model)
top_story_exterior_exposed_roof.setDefaultValue(true)
args << top_story_exterior_exposed_roof
# Make argument for story_multiplier
choices = OpenStudio::StringVector.new
choices << 'None'
choices << 'Basements Ground Mid Top'
# choices << "Basements Ground Midx5 Top"
- story_multiplier = OpenStudio::Measure::OSArgument.makeChoiceArgument('story_multiplier', choices, true)
- story_multiplier.setDisplayName('Calculation Method for Story Multiplier')
- story_multiplier.setDefaultValue('Basements Ground Mid Top')
- args << story_multiplier
+ story_multiplier_method = OpenStudio::Measure::OSArgument.makeChoiceArgument('story_multiplier_method', choices, true)
+ story_multiplier_method.setDisplayName('Calculation Method for Story Multiplier')
+ story_multiplier_method.setDefaultValue('Basements Ground Mid Top')
+ args << story_multiplier_method
# make an argument for make_mid_story_surfaces_adiabatic (added to avoid issues with intersect and to lower surface count when using individual stories sliced)
make_mid_story_surfaces_adiabatic = OpenStudio::Measure::OSArgument.makeBoolArgument('make_mid_story_surfaces_adiabatic', true)
@@ -314,15 +314,15 @@ def arguments(model)
top_story_exterior_exposed_roof.setDefaultValue(true)
args << top_story_exterior_exposed_roof
- # Make argument for story_multiplier
+ # Make argument for story_multiplier_method
choices = OpenStudio::StringVector.new
choices << 'None'
diff --git a/lib/measures/create_bar_from_space_type_ratios/measure.rb b/lib/measures/create_bar_from_space_type_ratios/measure.rb
index 15ca9638..7525ba6a 100644
--- a/lib/measures/create_bar_from_space_type_ratios/measure.rb
+++ b/lib/measures/create_bar_from_space_type_ratios/measure.rb
@@ -262,15 +262,15 @@ def arguments(model)
top_story_exterior_exposed_roof.setDefaultValue(true)
args << top_story_exterior_exposed_roof
# Make argument for story_multiplier
choices = OpenStudio::StringVector.new
choices << 'None'
choices << 'Basements Ground Mid Top'
# choices << "Basements Ground Midx5 Top"
- story_multiplier = OpenStudio::Measure::OSArgument.makeChoiceArgument('story_multiplier', choices, true)
- story_multiplier.setDisplayName('Calculation Method for Story Multiplier')
- story_multiplier.setDefaultValue('Basements Ground Mid Top')
- args << story_multiplier
+ story_multiplier_method = OpenStudio::Measure::OSArgument.makeChoiceArgument('story_multiplier_method', choices, true)
+ story_multiplier_method.setDisplayName('Calculation Method for Story Multiplier')
+ story_multiplier_method.setDefaultValue('Basements Ground Mid Top')
+ args << story_multiplier_method
# make an argument for make_mid_story_surfaces_adiabatic (added to avoid issues with intersect and to lower surface count when using individual stories sliced)
make_mid_story_surfaces_adiabatic = OpenStudio::Measure::OSArgument.makeBoolArgument('make_mid_story_surfaces_adiabatic', true)
@@ -262,15 +262,15 @@ def arguments(model)
top_story_exterior_exposed_roof.setDefaultValue(true)
args << top_story_exterior_exposed_roof
- # Make argument for story_multiplier
+ # Make argument for story_multiplier_method
choices = OpenStudio::StringVector.new
choices << 'None'